Module cache

Module cache 

Modules

manifest

Functions

handle_clean
Errors
handle_restore
Restore cached Docker images from tar files in the given directory.
handle_save
Save all harmont-local/* images to a cache directory as tar files, write a manifest, and prune stale tars that no longer correspond to any known image.