dispatch

Function dispatch 

pub async fn dispatch(command: Command, ctx: RunContext) -> Result<i32>
Dispatch a parsed CLI command to the appropriate handler. Returns an exit code.

Errors

Returns an error if the dispatched handler returns one. The exact set of failures depends on the command (filesystem/Docker for run, plugin-registry IO for plugin, plugin runtime errors for external).