Thin wrapper around bollard for the local executor.
Operations: pull images, start containers (long-lived sleep), exec commands streaming stdout/stderr, commit container to image, look up images by tag, stop and remove containers.
Thin wrapper around bollard for the local executor.
Operations: pull images, start containers (long-lived sleep), exec commands streaming stdout/stderr, commit container to image, look up images by tag, stop and remove containers.