write_archive

Function write_archive 

pub fn write_archive(source_dir: &Path, w: impl Write) -> Result<()>
Write a tar.gz archive of source_dir into w.

Errors

Returns an error if walking the source tree surfaces an I/O or permission error, if a file cannot be appended to the archive, or if the gzip stream cannot be finalised on the destination writer.