install

Function install 

pub fn install(state: Arc<OrchestratorState>)
Install per-run state for the duration of an orchestrator run.

Panics

Panics if state is installed twice — the host runs one orchestrator at a time for plan 2.